@@ -220,7 +220,7 @@ class FarBoxRenderer(m.HtmlRenderer):
 
     def header(self, content, level):
         hash_name = ""
-        hash_name_c = re.search("^#.*?[^#](#[0-9\w]+$)", content, flags=re.I)
+        hash_name_c = re.search("[^#]+(#[0-9\w]+$)", content, flags=re.I)
         if hash_name_c:
             hash_name = hash_name_c.group(1).lstrip("#")
             content = re.sub("(#[0-9\w]+$)", "", content, flags=re.I)
